AnimationFrame

Struct AnimationFrame 

pub struct AnimationFrame {
    pub frame_x: usize,
    pub frame_y: usize,
    pub width: usize,
    pub height: usize,
    pub duration: usize,
    pub alpha_blending: bool,
    pub disopse: bool,
    pub frame: Vec<u8>,
    pub alpha: Option<Vec<u8>>,
}
One animation frame entry parsed from an ANMF chunk.

Fields

frame_x: usize

Frame x offset on the animation canvas in pixels.

frame_y: usize

Frame y offset on the animation canvas in pixels.

width: usize

Frame width in pixels.

height: usize

Frame height in pixels.

duration: usize

Frame duration in milliseconds.

alpha_blending: bool

Whether the frame should be alpha-blended onto the canvas.

disopse: bool

Whether the frame should be disposed to background after display.

frame: Vec<u8>

Raw VP8 or VP8L frame payload.

alpha: Option<Vec<u8>>

Optional raw ALPH payload associated with the frame.