DecoderError

Enum DecoderError 

pub enum DecoderError {
    InvalidParam(&'static str),
    NotEnoughData(&'static str),
    Bitstream(&'static str),
    Unsupported(&'static str),
}
Error type used by decoding and parsing entry points.

Variants



InvalidParam(&'static str)

A caller-provided buffer size or dimension is invalid.



NotEnoughData(&'static str)

The input ended before a required structure was fully available.



Bitstream(&'static str)

The bitstream violates the WebP container or codec format.



Unsupported(&'static str)

The input uses a feature that is intentionally not implemented.